#[repr(C)]pub struct UpdateMetadataFieldAction {
pub extension_index: u8,
pub field_type: u8,
pub key: Vec<u8>,
pub value: Vec<u8>,
}Fields
extension_index: u8field_type: u8key: Vec<u8>value: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for UpdateMetadataFieldAction
impl BorshDeserialize for UpdateMetadataFieldAction
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateMetadataFieldAction
impl Clone for UpdateMetadataFieldAction
Sourcefn clone(&self) -> UpdateMetadataFieldAction
fn clone(&self) -> UpdateMetadataFieldAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateMetadataFieldAction
impl Debug for UpdateMetadataFieldAction
Sourceimpl<'a> ZeroCopyAt<'a> for UpdateMetadataFieldAction
impl<'a> ZeroCopyAt<'a> for UpdateMetadataFieldAction
type ZeroCopyAt = ZUpdateMetadataFieldAction<'a>
fn zero_copy_at( __remaining_bytes: &'a [u8], ) -> Result<(Self::ZeroCopyAt, &'a [u8]), ZeroCopyError>
Sourceimpl ZeroCopyStructInner for UpdateMetadataFieldAction
impl ZeroCopyStructInner for UpdateMetadataFieldAction
type ZeroCopyInner = ZUpdateMetadataFieldAction<'static>